@@ -50,6 +50,10 @@ from .type_defs import (
     GetImageRecipeResponseTypeDef,
     GetImageResponseTypeDef,
     GetInfrastructureConfigurationResponseTypeDef,
+    GetWorkflowExecutionResponseTypeDef,
+    GetWorkflowStepExecutionResponseTypeDef,
+    ImageScanFindingsFilterTypeDef,
+    ImageScanningConfigurationTypeDef,
     ImageTestsConfigurationTypeDef,
     ImportComponentResponseTypeDef,
     ImportVmImageResponseTypeDef,
@@ -65,9 +69,13 @@ from .type_defs import (
     ListImagePipelineImagesResponseTypeDef,
     ListImagePipelinesResponseTypeDef,
     ListImageRecipesResponseTypeDef,
+    ListImageScanFindingAggregationsResponseTypeDef,
+    ListImageScanFindingsResponseTypeDef,
     ListImagesResponseTypeDef,
     ListInfrastructureConfigurationsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    ListWorkflowExecutionsResponseTypeDef,
+    ListWorkflowStepExecutionsResponseTypeDef,
     LoggingTypeDef,
     PutComponentPolicyResponseTypeDef,
     PutContainerRecipePolicyResponseTypeDef,
@@ -238,7 +246,8 @@ class imagebuilderClient(BaseClient):
         distributionConfigurationArn: str = ...,
         imageTestsConfiguration: ImageTestsConfigurationTypeDef = ...,
         enhancedImageMetadataEnabled: bool = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        imageScanningConfiguration: ImageScanningConfigurationTypeDef = ...
     ) -> CreateImageResponseTypeDef:
         """
         Creates a new image.
@@ -261,7 +270,8 @@ class imagebuilderClient(BaseClient):
         enhancedImageMetadataEnabled: bool = ...,
         schedule: ScheduleTypeDef = ...,
         status: PipelineStatusType = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        imageScanningConfiguration: ImageScanningConfigurationTypeDef = ...
     ) -> CreateImagePipelineResponseTypeDef:
         """
         Creates a new image pipeline.
@@ -488,6 +498,28 @@ class imagebuilderClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#get_infrastructure_configuration)
         """
 
+    def get_workflow_execution(
+        self, *, workflowExecutionId: str
+    ) -> GetWorkflowExecutionResponseTypeDef:
+        """
+        Get the runtime information that was logged for a specific runtime instance of
+        the workflow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.get_workflow_execution)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#get_workflow_execution)
+        """
+
+    def get_workflow_step_execution(
+        self, *, stepExecutionId: str
+    ) -> GetWorkflowStepExecutionResponseTypeDef:
+        """
+        Get the runtime information that was logged for a specific runtime instance of
+        the workflow step.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.get_workflow_step_execution)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#get_workflow_step_execution)
+        """
+
     def import_component(
         self,
         *,
@@ -650,6 +682,30 @@ class imagebuilderClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_image_recipes)
         """
 
+    def list_image_scan_finding_aggregations(
+        self, *, filter: FilterTypeDef = ..., nextToken: str = ...
+    ) -> ListImageScanFindingAggregationsResponseTypeDef:
+        """
+        Returns a list of image scan aggregations for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.list_image_scan_finding_aggregations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_image_scan_finding_aggregations)
+        """
+
+    def list_image_scan_findings(
+        self,
+        *,
+        filters: Sequence[ImageScanFindingsFilterTypeDef] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
+    ) -> ListImageScanFindingsResponseTypeDef:
+        """
+        Returns a list of image scan findings for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.list_image_scan_findings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_image_scan_findings)
+        """
+
     def list_images(
         self,
         *,
@@ -685,6 +741,28 @@ class imagebuilderClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_tags_for_resource)
         """
 
+    def list_workflow_executions(
+        self, *, imageBuildVersionArn: str, maxResults: int = ..., nextToken: str = ...
+    ) -> ListWorkflowExecutionsResponseTypeDef:
+        """
+        Returns a list of workflow runtime instance metadata objects for a specific
+        image build version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.list_workflow_executions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_workflow_executions)
+        """
+
+    def list_workflow_step_executions(
+        self, *, workflowExecutionId: str, maxResults: int = ..., nextToken: str = ...
+    ) -> ListWorkflowStepExecutionsResponseTypeDef:
+        """
+        Shows runtime data for each step in a runtime instance of the workflow that you
+        specify in the request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.list_workflow_step_executions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_workflow_step_executions)
+        """
+
     def put_component_policy(
         self, *, componentArn: str, policy: str
     ) -> PutComponentPolicyResponseTypeDef:
@@ -777,7 +855,8 @@ class imagebuilderClient(BaseClient):
         imageTestsConfiguration: ImageTestsConfigurationTypeDef = ...,
         enhancedImageMetadataEnabled: bool = ...,
         schedule: ScheduleTypeDef = ...,
-        status: PipelineStatusType = ...
+        status: PipelineStatusType = ...,
+        imageScanningConfiguration: ImageScanningConfigurationTypeDef = ...
     ) -> UpdateImagePipelineResponseTypeDef:
         """
         Updates an image pipeline.
