@@ -28,6 +28,7 @@ __all__ = (
     "ContainerTypeType",
     "DiskImageFormatType",
     "EbsVolumeTypeType",
+    "ImageScanStatusType",
     "ImageSourceType",
     "ImageStatusType",
     "ImageTypeType",
@@ -35,6 +36,10 @@ __all__ = (
     "PipelineExecutionStartConditionType",
     "PipelineStatusType",
     "PlatformType",
+    "WorkflowExecutionStatusType",
+    "WorkflowStepExecutionRollbackStatusType",
+    "WorkflowStepExecutionStatusType",
+    "WorkflowTypeType",
     "imagebuilderServiceName",
     "ServiceName",
     "ResourceServiceName",
@@ -49,6 +54,9 @@ ContainerRepositoryServiceType = Literal["ECR"]
 ContainerTypeType = Literal["DOCKER"]
 DiskImageFormatType = Literal["RAW", "VHD", "VMDK"]
 EbsVolumeTypeType = Literal["gp2", "gp3", "io1", "io2", "sc1", "st1", "standard"]
+ImageScanStatusType = Literal[
+    "ABANDONED", "COLLECTING", "COMPLETED", "FAILED", "PENDING", "SCANNING", "TIMED_OUT"
+]
 ImageSourceType = Literal["AMAZON_MANAGED", "AWS_MARKETPLACE", "CUSTOM", "IMPORTED"]
 ImageStatusType = Literal[
     "AVAILABLE",
@@ -70,6 +78,18 @@ PipelineExecutionStartConditionType = Literal[
 ]
 PipelineStatusType = Literal["DISABLED", "ENABLED"]
 PlatformType = Literal["Linux", "Windows"]
+WorkflowExecutionStatusType = Literal[
+    "COMPLETED",
+    "FAILED",
+    "PENDING",
+    "ROLLBACK_COMPLETED",
+    "ROLLBACK_IN_PROGRESS",
+    "RUNNING",
+    "SKIPPED",
+]
+WorkflowStepExecutionRollbackStatusType = Literal["COMPLETED", "FAILED", "RUNNING", "SKIPPED"]
+WorkflowStepExecutionStatusType = Literal["COMPLETED", "FAILED", "PENDING", "RUNNING", "SKIPPED"]
+WorkflowTypeType = Literal["BUILD", "DISTRIBUTION", "TEST"]
 imagebuilderServiceName = Literal["imagebuilder"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -86,6 +106,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -125,6 +146,7 @@ ServiceName = Literal[
     "cloudsearch",
     "cloudsearchdomain",
     "cloudtrail",
+    "cloudtrail-data",
     "cloudwatch",
     "codeartifact",
     "codebuild",
@@ -132,6 +154,7 @@ ServiceName = Literal[
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -218,6 +241,7 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -236,6 +260,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
@@ -279,6 +304,7 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
@@ -305,8 +331,11 @@ ServiceName = Literal[
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -394,10 +423,13 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
+    "verifiedpermissions",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
